import 'dart:async';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:clipboard/clipboard.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-image-widget-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkCardImageWithBottomWidget extends StatefulWidget {
  const VgkCardImageWithBottomWidget(
      {Key key,
      this.mainScreenAnimationController,
      this.mainScreenAnimation,
      this.data})
      : super(key: key);

  final AnimationController mainScreenAnimationController;
  final Animation<dynamic> mainScreenAnimation;
  final VgkCardImageWidgetModel data;
  @override
  _VgkCardImageWithBottomWidgetState createState() =>
      _VgkCardImageWithBottomWidgetState();
}

class _VgkCardImageWithBottomWidgetState
    extends State<VgkCardImageWithBottomWidget> with TickerProviderStateMixin {
  AnimationController animationController;

  @override
  void initState() {
    animationController = AnimationController(
      duration: Duration(milliseconds: VgkProGamingTheme.milliseconds),
      vsync: this,
    );
    super.initState();
  }

  Future<bool> getData() async {
    await Future<dynamic>.delayed(const Duration(milliseconds: 50));
    return true;
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: widget.mainScreenAnimationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: widget.mainScreenAnimation,
          child: Transform(
            transform:
                VgkProGamingTheme.subTransform(widget.mainScreenAnimation),
            child: Container(
              child: Card(
                child: Container(
                  child: Column(
                    children: [
                      Padding(
                        padding: EdgeInsets.fromLTRB(12, 0, 12, 12),
                        child: Row(
                          children: <Widget>[
                            Text(
                              widget.data.key,
                              textAlign: TextAlign.left,
                              style: VgkProGamingTheme.h2,
                            ),
                            Spacer(),
                            new ButtonBar(
                              children: <Widget>[
                                Visibility(
                                  visible:
                                      widget.data.bgmi == null ? false : true,
                                  child: Row(
                                    mainAxisSize: MainAxisSize.min,
                                    children: <Widget>[
                                      new IconButton(
                                        icon: Icon(
                                          Icons.copy,
                                          color: Colors.redAccent,
                                        ),
                                        onPressed: () {
                                          FlutterClipboard.copy(
                                              widget.data.bgmi);
                                        },
                                      ),
                                      Text("Bgmi"),
                                    ],
                                  ),
                                ),
                                Visibility(
                                  visible:
                                      widget.data.global == null ? false : true,
                                  child: Row(
                                    mainAxisSize: MainAxisSize.min,
                                    children: <Widget>[
                                      new IconButton(
                                        icon: Icon(
                                          Icons.copy,
                                          color: Colors.redAccent,
                                        ),
                                        onPressed: () {
                                          FlutterClipboard.copy(
                                            widget.data.global,
                                          );
                                        },
                                      ),
                                      Text("global"),
                                    ],
                                  ),
                                )
                              ],
                            )
                          ],
                        ),
                      ),
                      AspectRatio(
                        aspectRatio: 2,
                        child: CachedNetworkImage(
                          imageUrl: widget.data.src,
                          fit: BoxFit.fill,
                          progressIndicatorBuilder:
                              (context, url, downloadProgress) =>
                                  CircularProgressIndicator(
                                      value: downloadProgress.progress),
                          errorWidget: (context, url, error) =>
                              Icon(Icons.error),
                        ),
                      ),
                    ],
                  ),
                ),
              ),
              decoration: new BoxDecoration(
                boxShadow: [
                  new BoxShadow(
                    color: Colors.grey.shade500,
                    blurRadius: 20.0,
                  ),
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}
